==> ubuntu_localizations-0.0.3.tar.gz: lib/src/l10n/ubuntu_localizations_zh.dart <==
import 'ubuntu_localizations.dart';

/// The translations for Chinese (`zh`).
class UbuntuLocalizationsZh extends UbuntuLocalizations {
  UbuntuLocalizationsZh([String locale = 'zh']) : super(locale);

  @override
  String get countryCode => 'CN';

  @override
  String get languageName => '中文（简体）';

  @override
  String get backAction => '返回';

  @override
  String get continueAction => '继续';

  @override
  String get strongPassword => '强密码';

  @override
  String get fairPassword => '公平密码';

  @override
  String get goodPassword => '好的密码';

  @override
  String get weakPassword => '弱密码';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Control';

  @override
  String get metaKey => 'Meta';

  @override
  String get shiftKey => 'Shift';

  @override
  String get aboutLabel => 'About';

  @override
  String get addLabel => 'Add';

  @override
  String get allLabel => 'All';

  @override
  String get applyLabel => 'Apply';

  @override
  String get ascendingLabel => 'Ascending';

  @override
  String get backLabel => 'Back';

  @override
  String get boldLabel => 'Bold';

  @override
  String get bottomLabel => 'Bottom';

  @override
  String get cancelLabel => 'Cancel';

  @override
  String get centerLabel => 'Center';

  @override
  String get clearLabel => 'Clear';

  @override
  String get closeLabel => 'Close';

  @override
  String get colorLabel => 'Color';

  @override
  String get connectLabel => 'Connect';

  @override
  String get continueLabel => 'Continue';

  @override
  String get copyLabel => 'Copy';

  @override
  String get createLabel => 'Create';

  @override
  String get cutLabel => 'Cut';

  @override
  String get decreaseLabel => 'Decrease';

  @override
  String get deleteLabel => 'Delete';

  @override
  String get descendingLabel => 'Descending';

  @override
  String get discardLabel => 'Discard';

  @override
  String get disconnectLabel => 'Disconnect';

  @override
  String get doneLabel => 'Done';

  @override
  String get downloadLabel => 'Download';

  @override
  String get editLabel => 'Edit';

  @override
  String get enterLabel => 'Enter';

  @override
  String get errorLabel => 'Error';

  @override
  String get executeLabel => 'Execute';

  @override
  String get exitLabel => 'Exit';

  @override
  String get fileLabel => 'File';

  @override
  String get fillLabel => 'Fill';

  @override
  String get findLabel => 'Find';

  @override
  String get firstLabel => 'First';

  @override
  String get fontLabel => 'Font';

  @override
  String get forwardLabel => 'Forward';

  @override
  String get fullscreenLabel => 'Fullscreen';

  @override
  String get goBackLabel => 'Go Back';

  @override
  String get helpLabel => 'Help';

  @override
  String get homeLabel => 'Home';

  @override
  String get importLabel => 'Import';

  @override
  String get increaseLabel => 'Increase';

  @override
  String get indexLabel => 'Index';

  @override
  String get informationLabel => 'Information';

  @override
  String get insertLabel => 'Insert';

  @override
  String get italicLabel => 'Italic';

  @override
  String get landscapeLabel => 'Landscape';

  @override
  String get lastLabel => 'Last';

  @override
  String get leaveLabel => 'Leave';

  @override
  String get leftLabel => 'Left';

  @override
  String get mediaLabel => 'Media';

  @override
  String get networkLabel => 'Network';

  @override
  String get newLabel => 'New';

  @override
  String get nextLabel => 'Next';

  @override
  String get noLabel => 'No';

  @override
  String get noneLabel => 'None';

  @override
  String get normalLabel => 'Normal';

  @override
  String get okLabel => 'OK';

  @override
  String get openLabel => 'Open';

  @override
  String get pasteLabel => 'Paste';

  @override
  String get pauseLabel => 'Pause';

  @override
  String get playLabel => 'Play';

  @override
  String get portraitLabel => 'Portrait';

  @override
  String get preferencesLabel => 'Preferences';

  @override
  String get previousLabel => 'Previous';

  @override
  String get printLabel => 'Print';

  @override
  String get printPreviewLabel => 'Print Preview';

  @override
  String get propertiesLabel => 'Properties';

  @override
  String get questionLabel => 'Question';

  @override
  String get quitLabel => 'Quit';

  @override
  String get recordLabel => 'Record';

  @override
  String get redoLabel => 'Redo';

  @override
  String get refreshLabel => 'Refresh';

  @override
  String get removeLabel => 'Remove';

  @override
  String get renameLabel => 'Rename';

  @override
  String get resetLabel => 'Reset';

  @override
  String get restoreLabel => 'Restore';

  @override
  String get revertLabel => 'Revert';

  @override
  String get rewindLabel => 'Rewind';

  @override
  String get rightLabel => 'Right';

  @override
  String get saveAsLabel => 'Save As';

  @override
  String get saveLabel => 'Save';

  @override
  String get searchLabel => 'Search';

  @override
  String get selectAllLabel => 'Select All';

  @override
  String get selectLabel => 'Select';

  @override
  String get sendLabel => 'Send';

  @override
  String get sortLabel => 'Sort';

  @override
  String get stopLabel => 'Stop';

  @override
  String get strikeThroughLabel => 'Strike Through';

  @override
  String get submitLabel => 'Submit';

  @override
  String get topLabel => 'Top';

  @override
  String get undoLabel => 'Undo';

  @override
  String get updateLabel => 'Update';

  @override
  String get upLabel => 'Up';

  @override
  String get viewLabel => 'View';

  @override
  String get warningLabel => 'Warning';

  @override
  String get windowLabel => 'Window';

  @override
  String get yesLabel => 'Yes';

  @override
  String get zoomInLabel => 'Zoom In';

  @override
  String get zoomOutLabel => 'Zoom Out';
}

==> ubuntu_localizations-0.0.4.tar.gz: lib/src/l10n/ubuntu_localizations_zh.dart <==
import 'ubuntu_localizations.dart';

/// The translations for Chinese (`zh`).
class UbuntuLocalizationsZh extends UbuntuLocalizations {
  UbuntuLocalizationsZh([String locale = 'zh']) : super(locale);

  @override
  String get countryCode => 'CN';

  @override
  String get languageName => '中文（简体）';

  @override
  String get backAction => '返回';

  @override
  String get continueAction => '继续';

  @override
  String get strongPassword => '密码强度：强';

  @override
  String get fairPassword => '密码强度：合理';

  @override
  String get goodPassword => '密码强度：较好';

  @override
  String get weakPassword => '密码强度：较弱';

  @override
  String get altKey => 'Alt 键';

  @override
  String get controlKey => 'Control 键';

  @override
  String get metaKey => 'Meta 键';

  @override
  String get shiftKey => 'Shift 键';

  @override
  String get aboutLabel => '关于';

  @override
  String get addLabel => 'Add';

  @override
  String get allLabel => 'All';

  @override
  String get applyLabel => '应用';

  @override
  String get ascendingLabel => '向上滚动';

  @override
  String get backLabel => '返回';

  @override
  String get boldLabel => 'Bold';

  @override
  String get bottomLabel => 'Bottom';

  @override
  String get cancelLabel => '取消';

  @override
  String get centerLabel => 'Center';

  @override
  String get clearLabel => 'Clear';

  @override
  String get closeLabel => '关闭';

  @override
  String get colorLabel => 'Color';

  @override
  String get connectLabel => '连接';

  @override
  String get continueLabel => '继续';

  @override
  String get copyLabel => '复制';

  @override
  String get createLabel => '创建';

  @override
  String get cutLabel => '剪切';

  @override
  String get decreaseLabel => 'Decrease';

  @override
  String get deleteLabel => '删除';

  @override
  String get descendingLabel => '向下滚动';

  @override
  String get discardLabel => '舍弃';

  @override
  String get disconnectLabel => 'Disconnect';

  @override
  String get doneLabel => '完成';

  @override
  String get downloadLabel => '下载';

  @override
  String get editLabel => '编辑';

  @override
  String get enterLabel => 'Enter';

  @override
  String get errorLabel => '错误';

  @override
  String get executeLabel => '执行';

  @override
  String get exitLabel => '退出';

  @override
  String get fileLabel => '文件';

  @override
  String get fillLabel => 'Fill';

  @override
  String get findLabel => '查找';

  @override
  String get firstLabel => 'First';

  @override
  String get fontLabel => '字体';

  @override
  String get forwardLabel => '前进';

  @override
  String get fullscreenLabel => '全屏';

  @override
  String get goBackLabel => '后退';

  @override
  String get helpLabel => '帮助';

  @override
  String get homeLabel => 'Home';

  @override
  String get importLabel => '导入';

  @override
  String get increaseLabel => 'Increase';

  @override
  String get indexLabel => 'Index';

  @override
  String get informationLabel => '信息';

  @override
  String get insertLabel => '插入';

  @override
  String get italicLabel => 'Italic';

  @override
  String get landscapeLabel => 'Landscape';

  @override
  String get lastLabel => 'Last';

  @override
  String get leaveLabel => 'Leave';

  @override
  String get leftLabel => 'Left';

  @override
  String get mediaLabel => 'Media';

  @override
  String get networkLabel => 'Network';

  @override
  String get newLabel => 'New';

  @override
  String get nextLabel => 'Next';

  @override
  String get noLabel => 'No';

  @override
  String get noneLabel => 'None';

  @override
  String get normalLabel => 'Normal';

  @override
  String get okLabel => 'OK';

  @override
  String get openLabel => 'Open';

  @override
  String get pasteLabel => 'Paste';

  @override
  String get pauseLabel => 'Pause';

  @override
  String get playLabel => 'Play';

  @override
  String get portraitLabel => 'Portrait';

  @override
  String get preferencesLabel => 'Preferences';

  @override
  String get previousLabel => 'Previous';

  @override
  String get printLabel => 'Print';

  @override
  String get printPreviewLabel => 'Print Preview';

  @override
  String get propertiesLabel => 'Properties';

  @override
  String get questionLabel => 'Question';

  @override
  String get quitLabel => 'Quit';

  @override
  String get recordLabel => 'Record';

  @override
  String get redoLabel => 'Redo';

  @override
  String get refreshLabel => 'Refresh';

  @override
  String get removeLabel => 'Remove';

  @override
  String get renameLabel => 'Rename';

  @override
  String get resetLabel => 'Reset';

  @override
  String get restoreLabel => 'Restore';

  @override
  String get retryLabel => 'Retry';

  @override
  String get revertLabel => 'Revert';

  @override
  String get rewindLabel => 'Rewind';

  @override
  String get rightLabel => 'Right';

  @override
  String get saveAsLabel => 'Save As';

  @override
  String get saveLabel => 'Save';

  @override
  String get searchLabel => 'Search';

  @override
  String get selectAllLabel => 'Select All';

  @override
  String get selectLabel => 'Select';

  @override
  String get sendLabel => 'Send';

  @override
  String get skipLabel => 'Skip';

  @override
  String get sortLabel => 'Sort';

  @override
  String get stopLabel => 'Stop';

  @override
  String get strikeThroughLabel => 'Strike Through';

  @override
  String get submitLabel => 'Submit';

  @override
  String get topLabel => 'Top';

  @override
  String get undoLabel => 'Undo';

  @override
  String get updateLabel => 'Update';

  @override
  String get upLabel => 'Up';

  @override
  String get viewLabel => 'View';

  @override
  String get warningLabel => 'Warning';

  @override
  String get windowLabel => 'Window';

  @override
  String get yesLabel => 'Yes';

  @override
  String get zoomInLabel => 'Zoom In';

  @override
  String get zoomOutLabel => 'Zoom Out';
}
